==> samurai-graph-src-0.6.1.zip: samurai-graph-src-0.6.1/src/jp/riken/brain/ni/samuraigraph/figure/SGISymbolConstants.java <==
/*
 * 쐬F 2004/12/08
 *
 * TODO ̐ꂽt@C̃ev[gύXɂ͎QƁB
 * EBhE  ݒ  Java  R[hEX^C  R[hEev[g
 */
package jp.riken.brain.ni.samuraigraph.figure;


/**
 * @author kuromaru
 *
 * TODO ̐ꂽ^Rg̃ev[gύXɂ͎QƁB
 * EBhE  ݒ  Java  R[hEX^C  R[hEev[g
 */
public interface SGISymbolConstants
{

	
	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_VOID = -1;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_CIRCLE = 0;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_SQUARE = 1;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_DIAMOND = 2;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_TRIANGLE = 3;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_INVERTEDTRIANGLE = 4;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_CROSS = 5;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_PLUS = 6;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_TRANSVERSELINE = 7;


	/**
	 * 
	 */
	public static final String SYMBOL_NAME_VOID = "No Symbol";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_CIRCLE = "Circle";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_SQUARE = "Square";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_DIAMOND = "Diamond";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_TRIANGLE = "Triangle";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_INVERTED_TRIANGLE = "Inverted Triangle";


	// added from version 0.6.1
	// declared to maintain downward compatibility with the old releases
	public static final String SYMBOL_NAME_INVERTED_TRIANGLE_OLD = "I-Triangle";


	/**
	 * 
	 */
	public static final String SYMBOL_NAME_CROSS = "Cross";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_PLUS = "Plus";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_TRANSVERSE_LINE = "Transverse Line";



	public static final String TAG_NAME_SYMBOL = "Symbol";

	public static final String KEY_SYMBOL_SIZE = "Size";
	public static final String KEY_SYMBOL_TYPE = "Type";
	public static final String KEY_LINE_WIDTH = "LineWidth";
	public static final String KEY_LINE_COLOR = "LineColor";
	public static final String KEY_INNER_COLOR_LIST = "InnerColor";

	
}

==> samurai-graph-src-0.7.0.zip: samurai-graph-src-0.7.0/src/jp/riken/brain/ni/samuraigraph/figure/SGISymbolConstants.java <==
/*
 * 쐬F 2004/12/08
 *
 * TODO ̐ꂽt@C̃ev[gύXɂ͎QƁB
 * EBhE  ݒ  Java  R[hEX^C  R[hEev[g
 */
package jp.riken.brain.ni.samuraigraph.figure;


/**
 * @author kuromaru
 *
 * TODO ̐ꂽ^Rg̃ev[gύXɂ͎QƁB
 * EBhE  ݒ  Java  R[hEX^C  R[hEev[g
 */
public interface SGISymbolConstants
{

	
	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_VOID = -1;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_CIRCLE = 1;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_SQUARE = 2;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_DIAMOND = 3;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_TRIANGLE = 4;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_INVERTEDTRIANGLE = 5;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_CROSS = 6;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_PLUS = 7;


	/**
	 * 
	 */
	public static final int SYMBOL_TYPE_TRANSVERSELINE = 8;


	/**
	 * 
	 */
	public static final String SYMBOL_NAME_VOID = "No Symbol";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_CIRCLE = "Circle";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_SQUARE = "Square";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_DIAMOND = "Diamond";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_TRIANGLE = "Triangle";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_INVERTED_TRIANGLE = "Inverted Triangle";


	// added from version 0.6.1
	// declared to maintain downward compatibility with the old releases
	public static final String SYMBOL_NAME_INVERTED_TRIANGLE_OLD = "I-Triangle";


	/**
	 * 
	 */
	public static final String SYMBOL_NAME_CROSS = "Cross";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_PLUS = "Plus";

	/**
	 * 
	 */
	public static final String SYMBOL_NAME_TRANSVERSE_LINE = "Transverse Line";



	public static final String TAG_NAME_SYMBOL = "Symbol";

	public static final String KEY_SYMBOL_SIZE = "Size";
	public static final String KEY_SYMBOL_TYPE = "Type";
	public static final String KEY_SYMBOL_LINE_WIDTH = "LineWidth";
	public static final String KEY_SYMBOL_LINE_COLOR = "LineColor";
	public static final String KEY_SYMBOL_INNER_COLOR_LIST = "InnerColor";

	
}
